import React, { PureComponent, createElement, Fragment } from 'react'
import { Modal, ModalHeader, ModalBody, ModalFooter, Button } from 'reactstrap'
import hoistStatics from 'hoist-non-react-statics'

export default function withModalConfirm(c = {}) {
  const config = { ...c }

  return function wrapWithModalConfirm(WrappedComponent) {
    class AskModalConfirm extends PureComponent {

      state = {
        entry: null,
      }

      isModalOpen = () => this.state.entry !== null

      closeModal = () => this.setState({ entry: null })

      askConfirm = entry => this.setState({ entry })

      render() {
        return (
          <Fragment>
            {createElement(WrappedComponent, {
              ...this.props,
              askConfirm: this.askConfirm,
            })}
            <Modal isOpen={this.isModalOpen()} toggle={this.closeModal}>
              <ModalHeader toggle={this.closeModal}>Conferma eliminazione</ModalHeader>
              <ModalBody>
                {this.state.entry && config.message(this.state.entry)}
              </ModalBody>
              <ModalFooter>
                <Button color="danger" onClick={() => {
                  // this.props.delete(this.state.askDelete.id)
                  this.closeModal()
                }}>Elimina</Button>{' '}
                <Button color="secondary" onClick={this.closeModal}>Annulla</Button>
             </ModalFooter>
            </Modal>
          </Fragment>
        )
      }
    }

    return hoistStatics(AskModalConfirm, WrappedComponent)
  }
}
